This function is a wrapper to get records from GBIF using rgbif and return a
data.frame ready to be used in caretSDM.
Arguments
- s
charactervector of species names.- file
characterwith file to save the output. If not informed, data will not be saved on folder.- as_df
Should the output be a
dataframe? Default isFALSE, returning aoccurrencesobject.- ...
Arguments to pass on
rgbif::occ_data().