Skip to contents

This function allows to download data from WorldClim v.2.1 (https://www.worldclim.org/data/index.html) considering multiple GCMs, time periods and SSPs.

Usage

WorldClim_data(path = NULL,
               period = "current",
               variable = "bioc",
               year = "2090",
               gcm = "mi",
               ssp = "585",
               resolution = 10)

Arguments

path

Directory path to save downloads.

period

Can be "current" or "future".

variable

Allows to specify which variables you want to retrieve Possible entries are: "tmax","tmin","prec" and/or "bioc".

year

Specify the year you want to retrieve data. Possible entries are: "2030", "2050", "2070" and/or "2090". You can use a vector to provide more than one entry.

gcm

GCMs to be considered in future scenarios. You can use a vector to provide more than one entry (see Details).

ssp

SSPs for future data. Possible entries are: "126", "245", "370" and/or "585". You can use a vector to provide more than one entry.

resolution

You can select one resolution from the following alternatives: 10, 5, 2.5 OR 30.

Value

If data is not downloaded, the function downloads the data and has no return value.

Details

This function will create a folder. All the data downloaded will be stored in this folder. Note that, despite being possible to retrieve a lot of data at once, it is not recommended to do so, since the data could be very heavy.

Possible values for GCMs are:

CodeGCM
acACCESS-CM2
aeACCESS-ESM1-5
bcBCC-CSM2-MR
caCanESM5
ccCanESM5-CanOE
ceCMCC-ESM2
cnCNRM-CM6-1
chCNRM-CM6-1-HR
crCNRM-ESM2-1
ecEC-Earth3-Veg
evEC-Earth3-Veg-LR
fiFIO-ESM-2-0
gfGFDL-ESM4
ggGISS-E2-1-G
ghGISS-E2-1-H
hgHadGEM3-GC31-LL
inINM-CM4-8
icINM-CM5-0
ipIPSL-CM6A-LR
meMIROC-ES2L
miMIROC6
mpMPI-ESM1-2-HR
mlMPI-ESM1-2-LR
mrMRI-ESM2-0
ukUKESM1-0-LL
allAll available GCMs

Author

Luíz Fernando Esser (luizesser@gmail.com) https://luizfesser.wordpress.com

Examples

## download data from multiple periods:
# year <- c("2050", "2090")
# WorldClim_data(path = "",
#               period = "future",
#               variable = "bioc",
#               year = year,
#               gcm = "mi",
#               ssp = "126",
#               resolution = 10)

## download data from one specific period
# WorldClim_data(path = "",
#               period = "future",
#               variable = "bioc",
#               year = "2070",
#               gcm = "mi",
#               ssp = "585",
#               resolution = 10)