This function calculates tSNE with presences and pseudoabsences data and returns a list of plots.
tsne_sdm(occ, pred = NULL, variables_selected = NULL)A list of plots, where each plot is a tSNE for a given pseudoabsence dataset.
A occurrences or input_sdm object.
A predictors object. If occ is of class input_sdm, then
pred is retrieved from it.
Variable to be used in t-SNE. It can also be 'vif', if previously calculated.
Luíz Fernando Esser (luizesser@gmail.com) https://luizfesser.wordpress.com