| background | R Documentation |
This function obtains background data given a set of predictors.
background(occ,
pred = NULL,
n = 10000,
n_set = 1,
proportion = NULL)
n_background(i)
background_data(i)
occ |
A |
pred |
A |
n |
|
n_set |
|
proportion |
|
i |
A |
background is used in the SDM workflow to obtain background data, a step necessary for
MaxEnt algorithm to run. This function helps avoid the use of pseudoabsence data in background
algorithms and the use of background data in pseudoabsence algorithms, a very common mistake.
n_background returns the number of background records obtained per species.
background_data returns a list of species names. Each species name will have a
lists with background data from class sf.
A occurrences_sdm or input_sdm object with background data.
Luíz Fernando Esser (luizesser@gmail.com) https://luizfesser.wordpress.com
link{input_sdm} pseudoabsences occurrences_sdm
# Create sdm_area object:
sa <- sdm_area(parana, cell_size = 25000, crs = 6933)
# Include predictors:
sa <- add_predictors(sa, bioc) |> select_predictors(c("bio1", "bio4", "bio12"))
# Include scenarios:
sa <- add_scenarios(sa)
# Create occurrences:
oc <- occurrences_sdm(occ, crs = 6933) |> join_area(sa)
# Create input_sdm:
i <- input_sdm(oc, sa)
# Pseudoabsence generation:
i <- background(i, proportion = 1) # All available data is obtained as background data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.