View source: R/pseudoabsences.R
| pseudoabsences | R Documentation |
This function obtains pseudoabsences given a set of predictors.
pseudoabsences(occ,
pred = NULL,
method = "random",
n_set = 10,
n_pa = NULL,
variables_selected = NULL,
th = 0,
size = 1,
crs = 4326)
n_pseudoabsences(i)
pseudoabsence_method(i)
pseudoabsence_data(i)
occ |
A |
pred |
A |
method |
Method to create pseudoabsences. One of: "random", "bioclim", "mahal.dist" or "buffer_sdm". |
n_set |
|
n_pa |
|
variables_selected |
A vector with variables names to be used while building pseudoabsences. Only used when method is not "random". |
th |
|
size |
|
crs |
|
i |
A |
pseudoabsences is used in the SDM workflow to obtain pseudoabsences, a step necessary for
most of the algorithms to run. We implemented three methods so far: "random", which is
self-explanatory, "bioclim", "mahal.dist" and "buffer_sdm". The two last are
built with the idea that pseudoabsences should be environmentally different from presences. Thus,
we implemented two presence-only methods to infer the distribution of the species. "bioclim" uses an
envelope approach (bioclimatic envelope), while "mahal.dist" uses a distance approach
(mahalanobis distance). th parameter enters here as a threshold to binarize those results.
Pseudoabsences are retrieved outside the projected distribution of the species.
n_pseudoabsences returns the number of pseudoabsences obtained per species.
pseudoabsence_method returns the method used to obtain pseudoabsences.
pseudoabsence_data returns a list of species names. Each species name will have a
lists with pseudoabsences data from class sf.
A occurrences_sdm or input_sdm object with pseudoabsence data.
Luíz Fernando Esser (luizesser@gmail.com) https://luizfesser.wordpress.com
link{input_sdm} background occurrences_sdm
# Create sdm_area object:
sa <- sdm_area(parana, cell_size = 25000, crs = 6933)
# Include predictors:
sa <- add_predictors(sa, bioc) |> select_predictors(c("bio1", "bio4", "bio12"))
# Include scenarios:
sa <- add_scenarios(sa)
# Create occurrences:
oc <- occurrences_sdm(occ, crs = 6933) |> join_area(sa)
# Create input_sdm:
i <- input_sdm(oc, sa)
# Pseudoabsence generation:
i <- pseudoabsences(i, method="random")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.