pseudoabsences is used in the SDM workflow to obtain pseudoabsences, a step necessary for
most of the algorithms to run. We implemented three methods so far: "random", which is
self-explanatory, "bioclim", "mahal.dist" and "buffer_sdm". The two last are
built with the idea that pseudoabsences should be environmentally different from presences. Thus,
we implemented two presence-only methods to infer the distribution of the species. "bioclim" uses an
envelope approach (bioclimatic envelope), while "mahal.dist" uses a distance approach
(mahalanobis distance). th parameter enters here as a threshold to binarize those results.
Pseudoabsences are retrieved outside the projected distribution of the species.
n_pseudoabsences returns the number of pseudoabsences obtained per species.
pseudoabsence_method returns the method used to obtain pseudoabsences.
pseudoabsence_data returns a list of species names. Each species name will have a
lists with pseudoabsences data from class sf.